package main

import (
	"bufio"
	"fmt"
	"image"
	"image/color"
	"image/png"
	"io/ioutil"
	"os"
	"path/filepath"
	"strconv"
	"strings"
)

func getColor(x int) color.RGBA {
	switch {
	case x == 0:
		return color.RGBA{0, 0, 255, 255}
	case x == 1:
		return color.RGBA{255, 0, 0, 255}
	case x == 2:
		return color.RGBA{0, 255, 0, 255}
	case x == 3:
		return color.RGBA{255, 255, 0, 255}
	case x == 4:
		return color.RGBA{255, 0, 255, 255}
	case x == 5:
		return color.RGBA{0, 255, 255, 255}
	case x == 6:
		return color.RGBA{255, 100, 100, 255}
	case x == 7:
		return color.RGBA{100, 100, 255, 255}
	case x == 8:
		return color.RGBA{100, 255, 255, 255}
	case x == 9:
		return color.RGBA{255, 255, 255, 255}
	}
	return color.RGBA{0, 0, 0, 255}
}

func main() {
	arguments := os.Args

	if len(arguments) != 5 {
		fmt.Printf("usage: %s x y PNG PiText\n", filepath.Base(arguments[0]))
		os.Exit(1)
	}

	x, _ := strconv.Atoi(arguments[1])
	y, _ := strconv.Atoi(arguments[2])
	PNGfile := arguments[3]
	input := arguments[4]

	f, err := os.OpenFile(PNGfile, os.O_CREATE|os.O_WRONLY, 0644)
	if err != nil {
		fmt.Println(err)
		os.Exit(1)
	}

	buf, err := ioutil.ReadFile(input)
	if err != nil {
		fmt.Println(err)
		os.Exit(1)
	}

	in := string(buf)
	s := bufio.NewScanner(strings.NewReader(in))
	s.Split(bufio.ScanRunes)

	m := image.NewNRGBA(image.Rectangle{Min: image.Point{0, 0}, Max: image.Point{x, y}})
	digitCounter := 0
	for s.Scan() {
		if digitCounter > x*y {
			break
		}

		if s.Text() == "." {
			continue
		}

		digit, _ := strconv.Atoi(s.Text())
		xx := int(digitCounter / x)
		yy := digitCounter % x
		c := getColor(digit)
		m.Set(xx, yy, c)
		digitCounter = digitCounter + 1
	}

	png.Encode(f, m)
	fmt.Println("Number of digits:", digitCounter)
}
